const assert = require('assert');
const { When, Then } = require('@cucumber/cucumber');

const { fixtures } = require('../../fixtures/server');

const mockValidConfig = fixtures.get('config-valid');

When('a mock notify API response is configured to return success', function () {
  const response = {};
  this.mockAxios.onPost(`${mockValidConfig.api}/notify`).reply(200, response);
});

When(
  'a mock notify API response is configured to return a {int} error',
  function (statusCode) {
    const statusMessages = {
      403: 'Token expired',
      503: 'Service unavailable',
    };
    this.mockAxios
      .onPost(`${mockValidConfig.api}/notify`)
      .reply(statusCode, { message: statusMessages[statusCode] });
  }
);

When('the broadcast method is called', function () {
  const message = fixtures.get('message-vehicle-status');
  this.message = message;
  const body = JSON.stringify(message);
  this.call = this.adapter.broadcast(body);
  this.callCounts.broadcast = this.adapter.getTrackedCalls('broadcast').length;
});

When('the broadcast method is called with is_retry on', function () {
  const message = fixtures.get('message-vehicle-status');
  this.message = message;
  const body = JSON.stringify(message);
  this.call = this.adapter.broadcast(body, true);
  this.callCounts.broadcast = this.adapter.getTrackedCalls('broadcast').length;
});

Then('the broadcast method was called with is_retry on', function () {
  let broadcastCalls = this.adapter.getTrackedCalls('broadcast');
  let lastCall = broadcastCalls[broadcastCalls.length - 1];
  assert.ok(lastCall.arguments[1].is_retry);
});

Then('the broadcast method is not called again', function () {
  let newBroadcastCallCount = this.adapter.getTrackedCalls('broadcast').length;
  assert.equal(this.callCounts.broadcast, newBroadcastCallCount);
});
